==> vtk6-6.3.0-11-armv6h.pkg.tar.xz: vtk/vtkImageChangeInformation.java <==
// java wrapper for vtkImageChangeInformation object
//

package vtk;
import vtk.*;

public class vtkImageChangeInformation extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInformationInputData_2(vtkImageData id0);
  public void SetInformationInputData(vtkImageData id0)
    { SetInformationInputData_2(id0); }

  private native long GetInformationInput_3();
  public vtkImageData GetInformationInput() {
    long temp = GetInformationInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetOutputExtentStart_4(int id0,int id1,int id2);
  public void SetOutputExtentStart(int id0,int id1,int id2)
    { SetOutputExtentStart_4(id0,id1,id2); }

  private native void SetOutputExtentStart_5(int id0[]);
  public void SetOutputExtentStart(int id0[])
    { SetOutputExtentStart_5(id0); }

  private native int[]  GetOutputExtentStart_6();
  public int[]  GetOutputExtentStart()
    { return GetOutputExtentStart_6(); }

  private native void SetOutputSpacing_7(double id0,double id1,double id2);
  public void SetOutputSpacing(double id0,double id1,double id2)
    { SetOutputSpacing_7(id0,id1,id2); }

  private native void SetOutputSpacing_8(double id0[]);
  public void SetOutputSpacing(double id0[])
    { SetOutputSpacing_8(id0); }

  private native double[] GetOutputSpacing_9();
  public double[] GetOutputSpacing()
    { return GetOutputSpacing_9(); }

  private native void SetOutputOrigin_10(double id0,double id1,double id2);
  public void SetOutputOrigin(double id0,double id1,double id2)
    { SetOutputOrigin_10(id0,id1,id2); }

  private native void SetOutputOrigin_11(double id0[]);
  public void SetOutputOrigin(double id0[])
    { SetOutputOrigin_11(id0); }

  private native double[] GetOutputOrigin_12();
  public double[] GetOutputOrigin()
    { return GetOutputOrigin_12(); }

  private native void SetCenterImage_13(int id0);
  public void SetCenterImage(int id0)
    { SetCenterImage_13(id0); }

  private native void CenterImageOn_14();
  public void CenterImageOn()
    { CenterImageOn_14(); }

  private native void CenterImageOff_15();
  public void CenterImageOff()
    { CenterImageOff_15(); }

  private native int GetCenterImage_16();
  public int GetCenterImage()
    { return GetCenterImage_16(); }

  private native void SetExtentTranslation_17(int id0,int id1,int id2);
  public void SetExtentTranslation(int id0,int id1,int id2)
    { SetExtentTranslation_17(id0,id1,id2); }

  private native void SetExtentTranslation_18(int id0[]);
  public void SetExtentTranslation(int id0[])
    { SetExtentTranslation_18(id0); }

  private native int[]  GetExtentTranslation_19();
  public int[]  GetExtentTranslation()
    { return GetExtentTranslation_19(); }

  private native void SetSpacingScale_20(double id0,double id1,double id2);
  public void SetSpacingScale(double id0,double id1,double id2)
    { SetSpacingScale_20(id0,id1,id2); }

  private native void SetSpacingScale_21(double id0[]);
  public void SetSpacingScale(double id0[])
    { SetSpacingScale_21(id0); }

  private native double[] GetSpacingScale_22();
  public double[] GetSpacingScale()
    { return GetSpacingScale_22(); }

  private native void SetOriginTranslation_23(double id0,double id1,double id2);
  public void SetOriginTranslation(double id0,double id1,double id2)
    { SetOriginTranslation_23(id0,id1,id2); }

  private native void SetOriginTranslation_24(double id0[]);
  public void SetOriginTranslation(double id0[])
    { SetOriginTranslation_24(id0); }

  private native double[] GetOriginTranslation_25();
  public double[] GetOriginTranslation()
    { return GetOriginTranslation_25(); }

  private native void SetOriginScale_26(double id0,double id1,double id2);
  public void SetOriginScale(double id0,double id1,double id2)
    { SetOriginScale_26(id0,id1,id2); }

  private native void SetOriginScale_27(double id0[]);
  public void SetOriginScale(double id0[])
    { SetOriginScale_27(id0); }

  private native double[] GetOriginScale_28();
  public double[] GetOriginScale()
    { return GetOriginScale_28(); }

  public vtkImageChangeInformation() { super(); }

  public vtkImageChangeInformation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv6h.pkg.tar.xz: vtk/vtkImageChangeInformation.java <==
// java wrapper for vtkImageChangeInformation object
//

package vtk;
import vtk.*;

public class vtkImageChangeInformation extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInformationInputData_2(vtkImageData id0);
  public void SetInformationInputData(vtkImageData id0)
    { SetInformationInputData_2(id0); }

  private native long GetInformationInput_3();
  public vtkImageData GetInformationInput() {
    long temp = GetInformationInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputExtentStart_4(int id0,int id1,int id2);
  public void SetOutputExtentStart(int id0,int id1,int id2)
    { SetOutputExtentStart_4(id0,id1,id2); }

  private native void SetOutputExtentStart_5(int id0[]);
  public void SetOutputExtentStart(int id0[])
    { SetOutputExtentStart_5(id0); }

  private native int[]  GetOutputExtentStart_6();
  public int[]  GetOutputExtentStart()
    { return GetOutputExtentStart_6(); }

  private native void SetOutputSpacing_7(double id0,double id1,double id2);
  public void SetOutputSpacing(double id0,double id1,double id2)
    { SetOutputSpacing_7(id0,id1,id2); }

  private native void SetOutputSpacing_8(double id0[]);
  public void SetOutputSpacing(double id0[])
    { SetOutputSpacing_8(id0); }

  private native double[] GetOutputSpacing_9();
  public double[] GetOutputSpacing()
    { return GetOutputSpacing_9(); }

  private native void SetOutputOrigin_10(double id0,double id1,double id2);
  public void SetOutputOrigin(double id0,double id1,double id2)
    { SetOutputOrigin_10(id0,id1,id2); }

  private native void SetOutputOrigin_11(double id0[]);
  public void SetOutputOrigin(double id0[])
    { SetOutputOrigin_11(id0); }

  private native double[] GetOutputOrigin_12();
  public double[] GetOutputOrigin()
    { return GetOutputOrigin_12(); }

  private native void SetCenterImage_13(int id0);
  public void SetCenterImage(int id0)
    { SetCenterImage_13(id0); }

  private native void CenterImageOn_14();
  public void CenterImageOn()
    { CenterImageOn_14(); }

  private native void CenterImageOff_15();
  public void CenterImageOff()
    { CenterImageOff_15(); }

  private native int GetCenterImage_16();
  public int GetCenterImage()
    { return GetCenterImage_16(); }

  private native void SetExtentTranslation_17(int id0,int id1,int id2);
  public void SetExtentTranslation(int id0,int id1,int id2)
    { SetExtentTranslation_17(id0,id1,id2); }

  private native void SetExtentTranslation_18(int id0[]);
  public void SetExtentTranslation(int id0[])
    { SetExtentTranslation_18(id0); }

  private native int[]  GetExtentTranslation_19();
  public int[]  GetExtentTranslation()
    { return GetExtentTranslation_19(); }

  private native void SetSpacingScale_20(double id0,double id1,double id2);
  public void SetSpacingScale(double id0,double id1,double id2)
    { SetSpacingScale_20(id0,id1,id2); }

  private native void SetSpacingScale_21(double id0[]);
  public void SetSpacingScale(double id0[])
    { SetSpacingScale_21(id0); }

  private native double[] GetSpacingScale_22();
  public double[] GetSpacingScale()
    { return GetSpacingScale_22(); }

  private native void SetOriginTranslation_23(double id0,double id1,double id2);
  public void SetOriginTranslation(double id0,double id1,double id2)
    { SetOriginTranslation_23(id0,id1,id2); }

  private native void SetOriginTranslation_24(double id0[]);
  public void SetOriginTranslation(double id0[])
    { SetOriginTranslation_24(id0); }

  private native double[] GetOriginTranslation_25();
  public double[] GetOriginTranslation()
    { return GetOriginTranslation_25(); }

  private native void SetOriginScale_26(double id0,double id1,double id2);
  public void SetOriginScale(double id0,double id1,double id2)
    { SetOriginScale_26(id0,id1,id2); }

  private native void SetOriginScale_27(double id0[]);
  public void SetOriginScale(double id0[])
    { SetOriginScale_27(id0); }

  private native double[] GetOriginScale_28();
  public double[] GetOriginScale()
    { return GetOriginScale_28(); }

  public vtkImageChangeInformation() { super(); }

  public vtkImageChangeInformation(long id) { super(id); }
  public native long   VTKInit();

}
